# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RewardDetails(object):
    """
    The overall monthly reward summary.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RewardDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param tenancy_id:
            The value to assign to the tenancy_id property of this RewardDetails.
        :type tenancy_id: str

        :param subscription_id:
            The value to assign to the subscription_id property of this RewardDetails.
        :type subscription_id: str

        :param currency:
            The value to assign to the currency property of this RewardDetails.
        :type currency: str

        :param rewards_rate:
            The value to assign to the rewards_rate property of this RewardDetails.
        :type rewards_rate: float

        :param total_rewards_available:
            The value to assign to the total_rewards_available property of this RewardDetails.
        :type total_rewards_available: float

        :param redemption_code:
            The value to assign to the redemption_code property of this RewardDetails.
        :type redemption_code: str

        """
        self.swagger_types = {
            'tenancy_id': 'str',
            'subscription_id': 'str',
            'currency': 'str',
            'rewards_rate': 'float',
            'total_rewards_available': 'float',
            'redemption_code': 'str'
        }

        self.attribute_map = {
            'tenancy_id': 'tenancyId',
            'subscription_id': 'subscriptionId',
            'currency': 'currency',
            'rewards_rate': 'rewardsRate',
            'total_rewards_available': 'totalRewardsAvailable',
            'redemption_code': 'redemptionCode'
        }

        self._tenancy_id = None
        self._subscription_id = None
        self._currency = None
        self._rewards_rate = None
        self._total_rewards_available = None
        self._redemption_code = None

    @property
    def tenancy_id(self):
        """
        Gets the tenancy_id of this RewardDetails.
        The OCID of the target tenancy.


        :return: The tenancy_id of this RewardDetails.
        :rtype: str
        """
        return self._tenancy_id

    @tenancy_id.setter
    def tenancy_id(self, tenancy_id):
        """
        Sets the tenancy_id of this RewardDetails.
        The OCID of the target tenancy.


        :param tenancy_id: The tenancy_id of this RewardDetails.
        :type: str
        """
        self._tenancy_id = tenancy_id

    @property
    def subscription_id(self):
        """
        Gets the subscription_id of this RewardDetails.
        The entitlement ID from MQS, which is the same as the subcription ID.


        :return: The subscription_id of this RewardDetails.
        :rtype: str
        """
        return self._subscription_id

    @subscription_id.setter
    def subscription_id(self, subscription_id):
        """
        Sets the subscription_id of this RewardDetails.
        The entitlement ID from MQS, which is the same as the subcription ID.


        :param subscription_id: The subscription_id of this RewardDetails.
        :type: str
        """
        self._subscription_id = subscription_id

    @property
    def currency(self):
        """
        Gets the currency of this RewardDetails.
        The currency unit for the reward amount.


        :return: The currency of this RewardDetails.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """
        Sets the currency of this RewardDetails.
        The currency unit for the reward amount.


        :param currency: The currency of this RewardDetails.
        :type: str
        """
        self._currency = currency

    @property
    def rewards_rate(self):
        """
        Gets the rewards_rate of this RewardDetails.
        The current Rewards percentage in decimal format.


        :return: The rewards_rate of this RewardDetails.
        :rtype: float
        """
        return self._rewards_rate

    @rewards_rate.setter
    def rewards_rate(self, rewards_rate):
        """
        Sets the rewards_rate of this RewardDetails.
        The current Rewards percentage in decimal format.


        :param rewards_rate: The rewards_rate of this RewardDetails.
        :type: float
        """
        self._rewards_rate = rewards_rate

    @property
    def total_rewards_available(self):
        """
        Gets the total_rewards_available of this RewardDetails.
        The total number of available rewards for a given subscription ID.


        :return: The total_rewards_available of this RewardDetails.
        :rtype: float
        """
        return self._total_rewards_available

    @total_rewards_available.setter
    def total_rewards_available(self, total_rewards_available):
        """
        Sets the total_rewards_available of this RewardDetails.
        The total number of available rewards for a given subscription ID.


        :param total_rewards_available: The total_rewards_available of this RewardDetails.
        :type: float
        """
        self._total_rewards_available = total_rewards_available

    @property
    def redemption_code(self):
        """
        Gets the redemption_code of this RewardDetails.
        The redemption code used in the billing center during the reward redemption process


        :return: The redemption_code of this RewardDetails.
        :rtype: str
        """
        return self._redemption_code

    @redemption_code.setter
    def redemption_code(self, redemption_code):
        """
        Sets the redemption_code of this RewardDetails.
        The redemption code used in the billing center during the reward redemption process


        :param redemption_code: The redemption_code of this RewardDetails.
        :type: str
        """
        self._redemption_code = redemption_code

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MonitoredResourceCredential(object):
    """
    Monitored Resource Credential Details
    """

    #: A constant which can be used with the credential_type property of a MonitoredResourceCredential.
    #: This constant has a value of "EXISTING"
    CREDENTIAL_TYPE_EXISTING = "EXISTING"

    #: A constant which can be used with the credential_type property of a MonitoredResourceCredential.
    #: This constant has a value of "PLAINTEXT"
    CREDENTIAL_TYPE_PLAINTEXT = "PLAINTEXT"

    #: A constant which can be used with the credential_type property of a MonitoredResourceCredential.
    #: This constant has a value of "ENCRYPTED"
    CREDENTIAL_TYPE_ENCRYPTED = "ENCRYPTED"

    def __init__(self, **kwargs):
        """
        Initializes a new MonitoredResourceCredential object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.stack_monitoring.models.PreExistingCredentials`
        * :class:`~oci.stack_monitoring.models.EncryptedCredentials`
        * :class:`~oci.stack_monitoring.models.PlainTextCredentials`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param source:
            The value to assign to the source property of this MonitoredResourceCredential.
        :type source: str

        :param name:
            The value to assign to the name property of this MonitoredResourceCredential.
        :type name: str

        :param type:
            The value to assign to the type property of this MonitoredResourceCredential.
        :type type: str

        :param description:
            The value to assign to the description property of this MonitoredResourceCredential.
        :type description: str

        :param credential_type:
            The value to assign to the credential_type property of this MonitoredResourceCredential.
            Allowed values for this property are: "EXISTING", "PLAINTEXT", "ENCRYPTED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type credential_type: str

        """
        self.swagger_types = {
            'source': 'str',
            'name': 'str',
            'type': 'str',
            'description': 'str',
            'credential_type': 'str'
        }

        self.attribute_map = {
            'source': 'source',
            'name': 'name',
            'type': 'type',
            'description': 'description',
            'credential_type': 'credentialType'
        }

        self._source = None
        self._name = None
        self._type = None
        self._description = None
        self._credential_type = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['credentialType']

        if type == 'EXISTING':
            return 'PreExistingCredentials'

        if type == 'ENCRYPTED':
            return 'EncryptedCredentials'

        if type == 'PLAINTEXT':
            return 'PlainTextCredentials'
        else:
            return 'MonitoredResourceCredential'

    @property
    def source(self):
        """
        Gets the source of this MonitoredResourceCredential.
        The source type and source name combination,delimited with (.) separator. {source type}.{source name} and source type max char limit is 63.


        :return: The source of this MonitoredResourceCredential.
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """
        Sets the source of this MonitoredResourceCredential.
        The source type and source name combination,delimited with (.) separator. {source type}.{source name} and source type max char limit is 63.


        :param source: The source of this MonitoredResourceCredential.
        :type: str
        """
        self._source = source

    @property
    def name(self):
        """
        Gets the name of this MonitoredResourceCredential.
        The name of the credential, within the context of the source.


        :return: The name of this MonitoredResourceCredential.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this MonitoredResourceCredential.
        The name of the credential, within the context of the source.


        :param name: The name of this MonitoredResourceCredential.
        :type: str
        """
        self._name = name

    @property
    def type(self):
        """
        Gets the type of this MonitoredResourceCredential.
        The type of the credential ( ex. JMXCreds,DBCreds).


        :return: The type of this MonitoredResourceCredential.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this MonitoredResourceCredential.
        The type of the credential ( ex. JMXCreds,DBCreds).


        :param type: The type of this MonitoredResourceCredential.
        :type: str
        """
        self._type = type

    @property
    def description(self):
        """
        Gets the description of this MonitoredResourceCredential.
        The user-specified textual description of the credential.


        :return: The description of this MonitoredResourceCredential.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this MonitoredResourceCredential.
        The user-specified textual description of the credential.


        :param description: The description of this MonitoredResourceCredential.
        :type: str
        """
        self._description = description

    @property
    def credential_type(self):
        """
        Gets the credential_type of this MonitoredResourceCredential.
        Type of credentials specified in the credentials element. Three possible values - EXISTING, PLAINTEXT and ENCRYPTED. * EXISTING  - Credential is already stored in agent and only credential name need to be passed for existing credential. * PLAINTEXT - The credential properties will have credentials in plain text format. * ENCRYPTED - The credential properties will have credentials stored in vault in encrypted format using KMS client which uses master key for encryption. The same master key will be used to decrypt the credentials before passing on to the management agent.

        Allowed values for this property are: "EXISTING", "PLAINTEXT", "ENCRYPTED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The credential_type of this MonitoredResourceCredential.
        :rtype: str
        """
        return self._credential_type

    @credential_type.setter
    def credential_type(self, credential_type):
        """
        Sets the credential_type of this MonitoredResourceCredential.
        Type of credentials specified in the credentials element. Three possible values - EXISTING, PLAINTEXT and ENCRYPTED. * EXISTING  - Credential is already stored in agent and only credential name need to be passed for existing credential. * PLAINTEXT - The credential properties will have credentials in plain text format. * ENCRYPTED - The credential properties will have credentials stored in vault in encrypted format using KMS client which uses master key for encryption. The same master key will be used to decrypt the credentials before passing on to the management agent.


        :param credential_type: The credential_type of this MonitoredResourceCredential.
        :type: str
        """
        allowed_values = ["EXISTING", "PLAINTEXT", "ENCRYPTED"]
        if not value_allowed_none_or_none_sentinel(credential_type, allowed_values):
            credential_type = 'UNKNOWN_ENUM_VALUE'
        self._credential_type = credential_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PatchHistorySummary(object):
    """
    Patch history of this cluster.
    """

    #: A constant which can be used with the lifecycle_state property of a PatchHistorySummary.
    #: This constant has a value of "INSTALLING"
    LIFECYCLE_STATE_INSTALLING = "INSTALLING"

    #: A constant which can be used with the lifecycle_state property of a PatchHistorySummary.
    #: This constant has a value of "INSTALLED"
    LIFECYCLE_STATE_INSTALLED = "INSTALLED"

    #: A constant which can be used with the lifecycle_state property of a PatchHistorySummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new PatchHistorySummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param version:
            The value to assign to the version property of this PatchHistorySummary.
        :type version: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this PatchHistorySummary.
            Allowed values for this property are: "INSTALLING", "INSTALLED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_updated:
            The value to assign to the time_updated property of this PatchHistorySummary.
        :type time_updated: datetime

        """
        self.swagger_types = {
            'version': 'str',
            'lifecycle_state': 'str',
            'time_updated': 'datetime'
        }

        self.attribute_map = {
            'version': 'version',
            'lifecycle_state': 'lifecycleState',
            'time_updated': 'timeUpdated'
        }

        self._version = None
        self._lifecycle_state = None
        self._time_updated = None

    @property
    def version(self):
        """
        **[Required]** Gets the version of this PatchHistorySummary.
        The version of the patch.


        :return: The version of this PatchHistorySummary.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this PatchHistorySummary.
        The version of the patch.


        :param version: The version of this PatchHistorySummary.
        :type: str
        """
        self._version = version

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this PatchHistorySummary.
        The status of this patch.

        Allowed values for this property are: "INSTALLING", "INSTALLED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this PatchHistorySummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this PatchHistorySummary.
        The status of this patch.


        :param lifecycle_state: The lifecycle_state of this PatchHistorySummary.
        :type: str
        """
        allowed_values = ["INSTALLING", "INSTALLED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this PatchHistorySummary.
        The time when the patch history was last updated.


        :return: The time_updated of this PatchHistorySummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this PatchHistorySummary.
        The time when the patch history was last updated.


        :param time_updated: The time_updated of this PatchHistorySummary.
        :type: datetime
        """
        self._time_updated = time_updated

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RemoveSubnetIpv6CidrDetails(object):
    """
    Details object for removing an IPv6 CIDR Block from a Subnet.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RemoveSubnetIpv6CidrDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param ipv6_cidr_block:
            The value to assign to the ipv6_cidr_block property of this RemoveSubnetIpv6CidrDetails.
        :type ipv6_cidr_block: str

        """
        self.swagger_types = {
            'ipv6_cidr_block': 'str'
        }

        self.attribute_map = {
            'ipv6_cidr_block': 'ipv6CidrBlock'
        }

        self._ipv6_cidr_block = None

    @property
    def ipv6_cidr_block(self):
        """
        **[Required]** Gets the ipv6_cidr_block of this RemoveSubnetIpv6CidrDetails.
        This field is not required and should only be specified when removing an IPv6 CIDR
        from a subnet's IPv6 address space.
        See`IPv6 Addresses`__.

        Example: `2001:0db8:0123::/64`

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm


        :return: The ipv6_cidr_block of this RemoveSubnetIpv6CidrDetails.
        :rtype: str
        """
        return self._ipv6_cidr_block

    @ipv6_cidr_block.setter
    def ipv6_cidr_block(self, ipv6_cidr_block):
        """
        Sets the ipv6_cidr_block of this RemoveSubnetIpv6CidrDetails.
        This field is not required and should only be specified when removing an IPv6 CIDR
        from a subnet's IPv6 address space.
        See`IPv6 Addresses`__.

        Example: `2001:0db8:0123::/64`

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm


        :param ipv6_cidr_block: The ipv6_cidr_block of this RemoveSubnetIpv6CidrDetails.
        :type: str
        """
        self._ipv6_cidr_block = ipv6_cidr_block

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdatePrivateEndpointDetails(object):
    """
    Update details for a private endpoint.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdatePrivateEndpointDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdatePrivateEndpointDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this UpdatePrivateEndpointDetails.
        :type description: str

        :param vcn_id:
            The value to assign to the vcn_id property of this UpdatePrivateEndpointDetails.
        :type vcn_id: str

        :param subnet_id:
            The value to assign to the subnet_id property of this UpdatePrivateEndpointDetails.
        :type subnet_id: str

        :param dns_zones:
            The value to assign to the dns_zones property of this UpdatePrivateEndpointDetails.
        :type dns_zones: list[str]

        :param nsg_id_list:
            The value to assign to the nsg_id_list property of this UpdatePrivateEndpointDetails.
        :type nsg_id_list: list[str]

        :param is_used_with_configuration_source_provider:
            The value to assign to the is_used_with_configuration_source_provider property of this UpdatePrivateEndpointDetails.
        :type is_used_with_configuration_source_provider: bool

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdatePrivateEndpointDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdatePrivateEndpointDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'description': 'str',
            'vcn_id': 'str',
            'subnet_id': 'str',
            'dns_zones': 'list[str]',
            'nsg_id_list': 'list[str]',
            'is_used_with_configuration_source_provider': 'bool',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'description': 'description',
            'vcn_id': 'vcnId',
            'subnet_id': 'subnetId',
            'dns_zones': 'dnsZones',
            'nsg_id_list': 'nsgIdList',
            'is_used_with_configuration_source_provider': 'isUsedWithConfigurationSourceProvider',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._description = None
        self._vcn_id = None
        self._subnet_id = None
        self._dns_zones = None
        self._nsg_id_list = None
        self._is_used_with_configuration_source_provider = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdatePrivateEndpointDetails.
        The private endpoint display name. Avoid entering confidential information.


        :return: The display_name of this UpdatePrivateEndpointDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdatePrivateEndpointDetails.
        The private endpoint display name. Avoid entering confidential information.


        :param display_name: The display_name of this UpdatePrivateEndpointDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this UpdatePrivateEndpointDetails.
        Description of the private endpoint. Avoid entering confidential information.


        :return: The description of this UpdatePrivateEndpointDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdatePrivateEndpointDetails.
        Description of the private endpoint. Avoid entering confidential information.


        :param description: The description of this UpdatePrivateEndpointDetails.
        :type: str
        """
        self._description = description

    @property
    def vcn_id(self):
        """
        Gets the vcn_id of this UpdatePrivateEndpointDetails.
        The `OCID`__ of the VCN for the private endpoint.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The vcn_id of this UpdatePrivateEndpointDetails.
        :rtype: str
        """
        return self._vcn_id

    @vcn_id.setter
    def vcn_id(self, vcn_id):
        """
        Sets the vcn_id of this UpdatePrivateEndpointDetails.
        The `OCID`__ of the VCN for the private endpoint.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param vcn_id: The vcn_id of this UpdatePrivateEndpointDetails.
        :type: str
        """
        self._vcn_id = vcn_id

    @property
    def subnet_id(self):
        """
        Gets the subnet_id of this UpdatePrivateEndpointDetails.
        The `OCID`__ of the subnet within the VCN for the private endpoint.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The subnet_id of this UpdatePrivateEndpointDetails.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this UpdatePrivateEndpointDetails.
        The `OCID`__ of the subnet within the VCN for the private endpoint.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param subnet_id: The subnet_id of this UpdatePrivateEndpointDetails.
        :type: str
        """
        self._subnet_id = subnet_id

    @property
    def dns_zones(self):
        """
        Gets the dns_zones of this UpdatePrivateEndpointDetails.
        DNS Proxy forwards any DNS FQDN queries over into the consumer DNS resolver if the DNS FQDN is included in the dns zones list otherwise it goes to service provider VCN resolver.


        :return: The dns_zones of this UpdatePrivateEndpointDetails.
        :rtype: list[str]
        """
        return self._dns_zones

    @dns_zones.setter
    def dns_zones(self, dns_zones):
        """
        Sets the dns_zones of this UpdatePrivateEndpointDetails.
        DNS Proxy forwards any DNS FQDN queries over into the consumer DNS resolver if the DNS FQDN is included in the dns zones list otherwise it goes to service provider VCN resolver.


        :param dns_zones: The dns_zones of this UpdatePrivateEndpointDetails.
        :type: list[str]
        """
        self._dns_zones = dns_zones

    @property
    def nsg_id_list(self):
        """
        Gets the nsg_id_list of this UpdatePrivateEndpointDetails.
        An array of network security group (NSG) `OCIDs`__ for the private endpoint.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The nsg_id_list of this UpdatePrivateEndpointDetails.
        :rtype: list[str]
        """
        return self._nsg_id_list

    @nsg_id_list.setter
    def nsg_id_list(self, nsg_id_list):
        """
        Sets the nsg_id_list of this UpdatePrivateEndpointDetails.
        An array of network security group (NSG) `OCIDs`__ for the private endpoint.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param nsg_id_list: The nsg_id_list of this UpdatePrivateEndpointDetails.
        :type: list[str]
        """
        self._nsg_id_list = nsg_id_list

    @property
    def is_used_with_configuration_source_provider(self):
        """
        Gets the is_used_with_configuration_source_provider of this UpdatePrivateEndpointDetails.
        When `true`, allows the private endpoint to be used with a configuration source provider.


        :return: The is_used_with_configuration_source_provider of this UpdatePrivateEndpointDetails.
        :rtype: bool
        """
        return self._is_used_with_configuration_source_provider

    @is_used_with_configuration_source_provider.setter
    def is_used_with_configuration_source_provider(self, is_used_with_configuration_source_provider):
        """
        Sets the is_used_with_configuration_source_provider of this UpdatePrivateEndpointDetails.
        When `true`, allows the private endpoint to be used with a configuration source provider.


        :param is_used_with_configuration_source_provider: The is_used_with_configuration_source_provider of this UpdatePrivateEndpointDetails.
        :type: bool
        """
        self._is_used_with_configuration_source_provider = is_used_with_configuration_source_provider

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdatePrivateEndpointDetails.
        Free-form tags associated with the resource. Each tag is a key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdatePrivateEndpointDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdatePrivateEndpointDetails.
        Free-form tags associated with the resource. Each tag is a key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdatePrivateEndpointDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdatePrivateEndpointDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdatePrivateEndpointDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdatePrivateEndpointDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdatePrivateEndpointDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SummarizeHostInsightResourceForecastTrendAggregation(object):
    """
    Forecast results from the selected time period.
    """

    #: A constant which can be used with the resource_metric property of a SummarizeHostInsightResourceForecastTrendAggregation.
    #: This constant has a value of "CPU"
    RESOURCE_METRIC_CPU = "CPU"

    #: A constant which can be used with the resource_metric property of a SummarizeHostInsightResourceForecastTrendAggregation.
    #: This constant has a value of "MEMORY"
    RESOURCE_METRIC_MEMORY = "MEMORY"

    #: A constant which can be used with the resource_metric property of a SummarizeHostInsightResourceForecastTrendAggregation.
    #: This constant has a value of "LOGICAL_MEMORY"
    RESOURCE_METRIC_LOGICAL_MEMORY = "LOGICAL_MEMORY"

    #: A constant which can be used with the usage_unit property of a SummarizeHostInsightResourceForecastTrendAggregation.
    #: This constant has a value of "CORES"
    USAGE_UNIT_CORES = "CORES"

    #: A constant which can be used with the usage_unit property of a SummarizeHostInsightResourceForecastTrendAggregation.
    #: This constant has a value of "GB"
    USAGE_UNIT_GB = "GB"

    #: A constant which can be used with the usage_unit property of a SummarizeHostInsightResourceForecastTrendAggregation.
    #: This constant has a value of "MBPS"
    USAGE_UNIT_MBPS = "MBPS"

    #: A constant which can be used with the usage_unit property of a SummarizeHostInsightResourceForecastTrendAggregation.
    #: This constant has a value of "IOPS"
    USAGE_UNIT_IOPS = "IOPS"

    #: A constant which can be used with the usage_unit property of a SummarizeHostInsightResourceForecastTrendAggregation.
    #: This constant has a value of "PERCENT"
    USAGE_UNIT_PERCENT = "PERCENT"

    #: A constant which can be used with the pattern property of a SummarizeHostInsightResourceForecastTrendAggregation.
    #: This constant has a value of "LINEAR"
    PATTERN_LINEAR = "LINEAR"

    #: A constant which can be used with the pattern property of a SummarizeHostInsightResourceForecastTrendAggregation.
    #: This constant has a value of "MONTHLY_SEASONS"
    PATTERN_MONTHLY_SEASONS = "MONTHLY_SEASONS"

    #: A constant which can be used with the pattern property of a SummarizeHostInsightResourceForecastTrendAggregation.
    #: This constant has a value of "MONTHLY_AND_YEARLY_SEASONS"
    PATTERN_MONTHLY_AND_YEARLY_SEASONS = "MONTHLY_AND_YEARLY_SEASONS"

    #: A constant which can be used with the pattern property of a SummarizeHostInsightResourceForecastTrendAggregation.
    #: This constant has a value of "WEEKLY_SEASONS"
    PATTERN_WEEKLY_SEASONS = "WEEKLY_SEASONS"

    #: A constant which can be used with the pattern property of a SummarizeHostInsightResourceForecastTrendAggregation.
    #: This constant has a value of "WEEKLY_AND_MONTHLY_SEASONS"
    PATTERN_WEEKLY_AND_MONTHLY_SEASONS = "WEEKLY_AND_MONTHLY_SEASONS"

    #: A constant which can be used with the pattern property of a SummarizeHostInsightResourceForecastTrendAggregation.
    #: This constant has a value of "WEEKLY_MONTHLY_AND_YEARLY_SEASONS"
    PATTERN_WEEKLY_MONTHLY_AND_YEARLY_SEASONS = "WEEKLY_MONTHLY_AND_YEARLY_SEASONS"

    #: A constant which can be used with the pattern property of a SummarizeHostInsightResourceForecastTrendAggregation.
    #: This constant has a value of "WEEKLY_AND_YEARLY_SEASONS"
    PATTERN_WEEKLY_AND_YEARLY_SEASONS = "WEEKLY_AND_YEARLY_SEASONS"

    #: A constant which can be used with the pattern property of a SummarizeHostInsightResourceForecastTrendAggregation.
    #: This constant has a value of "YEARLY_SEASONS"
    PATTERN_YEARLY_SEASONS = "YEARLY_SEASONS"

    def __init__(self, **kwargs):
        """
        Initializes a new SummarizeHostInsightResourceForecastTrendAggregation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param time_interval_start:
            The value to assign to the time_interval_start property of this SummarizeHostInsightResourceForecastTrendAggregation.
        :type time_interval_start: datetime

        :param time_interval_end:
            The value to assign to the time_interval_end property of this SummarizeHostInsightResourceForecastTrendAggregation.
        :type time_interval_end: datetime

        :param resource_metric:
            The value to assign to the resource_metric property of this SummarizeHostInsightResourceForecastTrendAggregation.
            Allowed values for this property are: "CPU", "MEMORY", "LOGICAL_MEMORY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type resource_metric: str

        :param usage_unit:
            The value to assign to the usage_unit property of this SummarizeHostInsightResourceForecastTrendAggregation.
            Allowed values for this property are: "CORES", "GB", "MBPS", "IOPS", "PERCENT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type usage_unit: str

        :param pattern:
            The value to assign to the pattern property of this SummarizeHostInsightResourceForecastTrendAggregation.
            Allowed values for this property are: "LINEAR", "MONTHLY_SEASONS", "MONTHLY_AND_YEARLY_SEASONS", "WEEKLY_SEASONS", "WEEKLY_AND_MONTHLY_SEASONS", "WEEKLY_MONTHLY_AND_YEARLY_SEASONS", "WEEKLY_AND_YEARLY_SEASONS", "YEARLY_SEASONS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type pattern: str

        :param historical_data:
            The value to assign to the historical_data property of this SummarizeHostInsightResourceForecastTrendAggregation.
        :type historical_data: list[oci.opsi.models.HistoricalDataItem]

        :param projected_data:
            The value to assign to the projected_data property of this SummarizeHostInsightResourceForecastTrendAggregation.
        :type projected_data: list[oci.opsi.models.ProjectedDataItem]

        """
        self.swagger_types = {
            'time_interval_start': 'datetime',
            'time_interval_end': 'datetime',
            'resource_metric': 'str',
            'usage_unit': 'str',
            'pattern': 'str',
            'historical_data': 'list[HistoricalDataItem]',
            'projected_data': 'list[ProjectedDataItem]'
        }

        self.attribute_map = {
            'time_interval_start': 'timeIntervalStart',
            'time_interval_end': 'timeIntervalEnd',
            'resource_metric': 'resourceMetric',
            'usage_unit': 'usageUnit',
            'pattern': 'pattern',
            'historical_data': 'historicalData',
            'projected_data': 'projectedData'
        }

        self._time_interval_start = None
        self._time_interval_end = None
        self._resource_metric = None
        self._usage_unit = None
        self._pattern = None
        self._historical_data = None
        self._projected_data = None

    @property
    def time_interval_start(self):
        """
        **[Required]** Gets the time_interval_start of this SummarizeHostInsightResourceForecastTrendAggregation.
        The start timestamp that was passed into the request.


        :return: The time_interval_start of this SummarizeHostInsightResourceForecastTrendAggregation.
        :rtype: datetime
        """
        return self._time_interval_start

    @time_interval_start.setter
    def time_interval_start(self, time_interval_start):
        """
        Sets the time_interval_start of this SummarizeHostInsightResourceForecastTrendAggregation.
        The start timestamp that was passed into the request.


        :param time_interval_start: The time_interval_start of this SummarizeHostInsightResourceForecastTrendAggregation.
        :type: datetime
        """
        self._time_interval_start = time_interval_start

    @property
    def time_interval_end(self):
        """
        **[Required]** Gets the time_interval_end of this SummarizeHostInsightResourceForecastTrendAggregation.
        The end timestamp that was passed into the request.


        :return: The time_interval_end of this SummarizeHostInsightResourceForecastTrendAggregation.
        :rtype: datetime
        """
        return self._time_interval_end

    @time_interval_end.setter
    def time_interval_end(self, time_interval_end):
        """
        Sets the time_interval_end of this SummarizeHostInsightResourceForecastTrendAggregation.
        The end timestamp that was passed into the request.


        :param time_interval_end: The time_interval_end of this SummarizeHostInsightResourceForecastTrendAggregation.
        :type: datetime
        """
        self._time_interval_end = time_interval_end

    @property
    def resource_metric(self):
        """
        **[Required]** Gets the resource_metric of this SummarizeHostInsightResourceForecastTrendAggregation.
        Defines the type of resource metric (CPU, Physical Memory, Logical Memory)

        Allowed values for this property are: "CPU", "MEMORY", "LOGICAL_MEMORY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The resource_metric of this SummarizeHostInsightResourceForecastTrendAggregation.
        :rtype: str
        """
        return self._resource_metric

    @resource_metric.setter
    def resource_metric(self, resource_metric):
        """
        Sets the resource_metric of this SummarizeHostInsightResourceForecastTrendAggregation.
        Defines the type of resource metric (CPU, Physical Memory, Logical Memory)


        :param resource_metric: The resource_metric of this SummarizeHostInsightResourceForecastTrendAggregation.
        :type: str
        """
        allowed_values = ["CPU", "MEMORY", "LOGICAL_MEMORY"]
        if not value_allowed_none_or_none_sentinel(resource_metric, allowed_values):
            resource_metric = 'UNKNOWN_ENUM_VALUE'
        self._resource_metric = resource_metric

    @property
    def usage_unit(self):
        """
        **[Required]** Gets the usage_unit of this SummarizeHostInsightResourceForecastTrendAggregation.
        Displays usage unit (CORES, GB)

        Allowed values for this property are: "CORES", "GB", "MBPS", "IOPS", "PERCENT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The usage_unit of this SummarizeHostInsightResourceForecastTrendAggregation.
        :rtype: str
        """
        return self._usage_unit

    @usage_unit.setter
    def usage_unit(self, usage_unit):
        """
        Sets the usage_unit of this SummarizeHostInsightResourceForecastTrendAggregation.
        Displays usage unit (CORES, GB)


        :param usage_unit: The usage_unit of this SummarizeHostInsightResourceForecastTrendAggregation.
        :type: str
        """
        allowed_values = ["CORES", "GB", "MBPS", "IOPS", "PERCENT"]
        if not value_allowed_none_or_none_sentinel(usage_unit, allowed_values):
            usage_unit = 'UNKNOWN_ENUM_VALUE'
        self._usage_unit = usage_unit

    @property
    def pattern(self):
        """
        **[Required]** Gets the pattern of this SummarizeHostInsightResourceForecastTrendAggregation.
        Time series patterns used in the forecasting.

        Allowed values for this property are: "LINEAR", "MONTHLY_SEASONS", "MONTHLY_AND_YEARLY_SEASONS", "WEEKLY_SEASONS", "WEEKLY_AND_MONTHLY_SEASONS", "WEEKLY_MONTHLY_AND_YEARLY_SEASONS", "WEEKLY_AND_YEARLY_SEASONS", "YEARLY_SEASONS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The pattern of this SummarizeHostInsightResourceForecastTrendAggregation.
        :rtype: str
        """
        return self._pattern

    @pattern.setter
    def pattern(self, pattern):
        """
        Sets the pattern of this SummarizeHostInsightResourceForecastTrendAggregation.
        Time series patterns used in the forecasting.


        :param pattern: The pattern of this SummarizeHostInsightResourceForecastTrendAggregation.
        :type: str
        """
        allowed_values = ["LINEAR", "MONTHLY_SEASONS", "MONTHLY_AND_YEARLY_SEASONS", "WEEKLY_SEASONS", "WEEKLY_AND_MONTHLY_SEASONS", "WEEKLY_MONTHLY_AND_YEARLY_SEASONS", "WEEKLY_AND_YEARLY_SEASONS", "YEARLY_SEASONS"]
        if not value_allowed_none_or_none_sentinel(pattern, allowed_values):
            pattern = 'UNKNOWN_ENUM_VALUE'
        self._pattern = pattern

    @property
    def historical_data(self):
        """
        **[Required]** Gets the historical_data of this SummarizeHostInsightResourceForecastTrendAggregation.
        Time series data used for the forecast analysis.


        :return: The historical_data of this SummarizeHostInsightResourceForecastTrendAggregation.
        :rtype: list[oci.opsi.models.HistoricalDataItem]
        """
        return self._historical_data

    @historical_data.setter
    def historical_data(self, historical_data):
        """
        Sets the historical_data of this SummarizeHostInsightResourceForecastTrendAggregation.
        Time series data used for the forecast analysis.


        :param historical_data: The historical_data of this SummarizeHostInsightResourceForecastTrendAggregation.
        :type: list[oci.opsi.models.HistoricalDataItem]
        """
        self._historical_data = historical_data

    @property
    def projected_data(self):
        """
        **[Required]** Gets the projected_data of this SummarizeHostInsightResourceForecastTrendAggregation.
        Time series data result of the forecasting analysis.


        :return: The projected_data of this SummarizeHostInsightResourceForecastTrendAggregation.
        :rtype: list[oci.opsi.models.ProjectedDataItem]
        """
        return self._projected_data

    @projected_data.setter
    def projected_data(self, projected_data):
        """
        Sets the projected_data of this SummarizeHostInsightResourceForecastTrendAggregation.
        Time series data result of the forecasting analysis.


        :param projected_data: The projected_data of this SummarizeHostInsightResourceForecastTrendAggregation.
        :type: list[oci.opsi.models.ProjectedDataItem]
        """
        self._projected_data = projected_data

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CallOperationConfig(object):
    """
    Holder for parameters names.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CallOperationConfig object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param in_fields:
            The value to assign to the in_fields property of this CallOperationConfig.
        :type in_fields: list[str]

        :param out_fields:
            The value to assign to the out_fields property of this CallOperationConfig.
        :type out_fields: list[str]

        :param call_attribute:
            The value to assign to the call_attribute property of this CallOperationConfig.
        :type call_attribute: oci.data_connectivity.models.AbstractCallAttribute

        :param push_down_operations:
            The value to assign to the push_down_operations property of this CallOperationConfig.
        :type push_down_operations: list[oci.data_connectivity.models.PushDownOperation]

        """
        self.swagger_types = {
            'in_fields': 'list[str]',
            'out_fields': 'list[str]',
            'call_attribute': 'AbstractCallAttribute',
            'push_down_operations': 'list[PushDownOperation]'
        }

        self.attribute_map = {
            'in_fields': 'inFields',
            'out_fields': 'outFields',
            'call_attribute': 'callAttribute',
            'push_down_operations': 'pushDownOperations'
        }

        self._in_fields = None
        self._out_fields = None
        self._call_attribute = None
        self._push_down_operations = None

    @property
    def in_fields(self):
        """
        Gets the in_fields of this CallOperationConfig.
        List of names of IN/INOUT parameters.


        :return: The in_fields of this CallOperationConfig.
        :rtype: list[str]
        """
        return self._in_fields

    @in_fields.setter
    def in_fields(self, in_fields):
        """
        Sets the in_fields of this CallOperationConfig.
        List of names of IN/INOUT parameters.


        :param in_fields: The in_fields of this CallOperationConfig.
        :type: list[str]
        """
        self._in_fields = in_fields

    @property
    def out_fields(self):
        """
        Gets the out_fields of this CallOperationConfig.
        List of names of OUT/INOUT parameters.


        :return: The out_fields of this CallOperationConfig.
        :rtype: list[str]
        """
        return self._out_fields

    @out_fields.setter
    def out_fields(self, out_fields):
        """
        Sets the out_fields of this CallOperationConfig.
        List of names of OUT/INOUT parameters.


        :param out_fields: The out_fields of this CallOperationConfig.
        :type: list[str]
        """
        self._out_fields = out_fields

    @property
    def call_attribute(self):
        """
        Gets the call_attribute of this CallOperationConfig.

        :return: The call_attribute of this CallOperationConfig.
        :rtype: oci.data_connectivity.models.AbstractCallAttribute
        """
        return self._call_attribute

    @call_attribute.setter
    def call_attribute(self, call_attribute):
        """
        Sets the call_attribute of this CallOperationConfig.

        :param call_attribute: The call_attribute of this CallOperationConfig.
        :type: oci.data_connectivity.models.AbstractCallAttribute
        """
        self._call_attribute = call_attribute

    @property
    def push_down_operations(self):
        """
        Gets the push_down_operations of this CallOperationConfig.
        List of push down operations.


        :return: The push_down_operations of this CallOperationConfig.
        :rtype: list[oci.data_connectivity.models.PushDownOperation]
        """
        return self._push_down_operations

    @push_down_operations.setter
    def push_down_operations(self, push_down_operations):
        """
        Sets the push_down_operations of this CallOperationConfig.
        List of push down operations.


        :param push_down_operations: The push_down_operations of this CallOperationConfig.
        :type: list[oci.data_connectivity.models.PushDownOperation]
        """
        self._push_down_operations = push_down_operations

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TimeAndVerticalScalingConfig(object):
    """
    Time of day and vertical scaling configuration.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TimeAndVerticalScalingConfig object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param time_recurrence:
            The value to assign to the time_recurrence property of this TimeAndVerticalScalingConfig.
        :type time_recurrence: str

        :param target_shape:
            The value to assign to the target_shape property of this TimeAndVerticalScalingConfig.
        :type target_shape: str

        :param target_ocpus_per_node:
            The value to assign to the target_ocpus_per_node property of this TimeAndVerticalScalingConfig.
        :type target_ocpus_per_node: int

        :param target_memory_per_node:
            The value to assign to the target_memory_per_node property of this TimeAndVerticalScalingConfig.
        :type target_memory_per_node: int

        """
        self.swagger_types = {
            'time_recurrence': 'str',
            'target_shape': 'str',
            'target_ocpus_per_node': 'int',
            'target_memory_per_node': 'int'
        }

        self.attribute_map = {
            'time_recurrence': 'timeRecurrence',
            'target_shape': 'targetShape',
            'target_ocpus_per_node': 'targetOcpusPerNode',
            'target_memory_per_node': 'targetMemoryPerNode'
        }

        self._time_recurrence = None
        self._target_shape = None
        self._target_ocpus_per_node = None
        self._target_memory_per_node = None

    @property
    def time_recurrence(self):
        """
        Gets the time_recurrence of this TimeAndVerticalScalingConfig.
        Day/time recurrence (specified following RFC 5545) at which to trigger autoscaling action. Currently only WEEKLY frequency is supported. Days of the week are specified using BYDAY field. Time of the day is specified using BYHOUR and BYMINUTE fields. Other fields are not supported.


        :return: The time_recurrence of this TimeAndVerticalScalingConfig.
        :rtype: str
        """
        return self._time_recurrence

    @time_recurrence.setter
    def time_recurrence(self, time_recurrence):
        """
        Sets the time_recurrence of this TimeAndVerticalScalingConfig.
        Day/time recurrence (specified following RFC 5545) at which to trigger autoscaling action. Currently only WEEKLY frequency is supported. Days of the week are specified using BYDAY field. Time of the day is specified using BYHOUR and BYMINUTE fields. Other fields are not supported.


        :param time_recurrence: The time_recurrence of this TimeAndVerticalScalingConfig.
        :type: str
        """
        self._time_recurrence = time_recurrence

    @property
    def target_shape(self):
        """
        Gets the target_shape of this TimeAndVerticalScalingConfig.
        For nodes with `fixed compute shapes`__, this value is the desired shape of each node. This value is not used for nodes with flexible compute shapes.

        __ https://docs.cloud.oracle.com/iaas/Content/bigdata/create-cluster.htm#cluster-plan-shape


        :return: The target_shape of this TimeAndVerticalScalingConfig.
        :rtype: str
        """
        return self._target_shape

    @target_shape.setter
    def target_shape(self, target_shape):
        """
        Sets the target_shape of this TimeAndVerticalScalingConfig.
        For nodes with `fixed compute shapes`__, this value is the desired shape of each node. This value is not used for nodes with flexible compute shapes.

        __ https://docs.cloud.oracle.com/iaas/Content/bigdata/create-cluster.htm#cluster-plan-shape


        :param target_shape: The target_shape of this TimeAndVerticalScalingConfig.
        :type: str
        """
        self._target_shape = target_shape

    @property
    def target_ocpus_per_node(self):
        """
        Gets the target_ocpus_per_node of this TimeAndVerticalScalingConfig.
        For nodes with `flexible compute shapes`__, this value is the desired OCPUs count on each node. This value is not used for nodes with fixed compute shapes.

        __ https://docs.cloud.oracle.com/iaas/Content/bigdata/create-cluster.htm#cluster-plan-shape


        :return: The target_ocpus_per_node of this TimeAndVerticalScalingConfig.
        :rtype: int
        """
        return self._target_ocpus_per_node

    @target_ocpus_per_node.setter
    def target_ocpus_per_node(self, target_ocpus_per_node):
        """
        Sets the target_ocpus_per_node of this TimeAndVerticalScalingConfig.
        For nodes with `flexible compute shapes`__, this value is the desired OCPUs count on each node. This value is not used for nodes with fixed compute shapes.

        __ https://docs.cloud.oracle.com/iaas/Content/bigdata/create-cluster.htm#cluster-plan-shape


        :param target_ocpus_per_node: The target_ocpus_per_node of this TimeAndVerticalScalingConfig.
        :type: int
        """
        self._target_ocpus_per_node = target_ocpus_per_node

    @property
    def target_memory_per_node(self):
        """
        Gets the target_memory_per_node of this TimeAndVerticalScalingConfig.
        For nodes with `flexible compute shapes`__, this value is the desired memory in GBs on each node. This value is not used for nodes with fixed compute shapes.

        __ https://docs.cloud.oracle.com/iaas/Content/bigdata/create-cluster.htm#cluster-plan-shape


        :return: The target_memory_per_node of this TimeAndVerticalScalingConfig.
        :rtype: int
        """
        return self._target_memory_per_node

    @target_memory_per_node.setter
    def target_memory_per_node(self, target_memory_per_node):
        """
        Sets the target_memory_per_node of this TimeAndVerticalScalingConfig.
        For nodes with `flexible compute shapes`__, this value is the desired memory in GBs on each node. This value is not used for nodes with fixed compute shapes.

        __ https://docs.cloud.oracle.com/iaas/Content/bigdata/create-cluster.htm#cluster-plan-shape


        :param target_memory_per_node: The target_memory_per_node of this TimeAndVerticalScalingConfig.
        :type: int
        """
        self._target_memory_per_node = target_memory_per_node

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .update_channel_details import UpdateChannelDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateSlackChannelDetails(UpdateChannelDetails):
    """
    Properties to update a Slack channel.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateSlackChannelDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.oda.models.UpdateSlackChannelDetails.type` attribute
        of this class is ``SLACK`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param description:
            The value to assign to the description property of this UpdateSlackChannelDetails.
        :type description: str

        :param type:
            The value to assign to the type property of this UpdateSlackChannelDetails.
            Allowed values for this property are: "ANDROID", "APPEVENT", "APPLICATION", "CORTANA", "FACEBOOK", "IOS", "MSTEAMS", "OSS", "OSVC", "SERVICECLOUD", "SLACK", "TEST", "TWILIO", "WEB", "WEBHOOK"
        :type type: str

        :param session_expiry_duration_in_milliseconds:
            The value to assign to the session_expiry_duration_in_milliseconds property of this UpdateSlackChannelDetails.
        :type session_expiry_duration_in_milliseconds: int

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateSlackChannelDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateSlackChannelDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param client_id:
            The value to assign to the client_id property of this UpdateSlackChannelDetails.
        :type client_id: str

        :param auth_success_url:
            The value to assign to the auth_success_url property of this UpdateSlackChannelDetails.
        :type auth_success_url: str

        :param auth_error_url:
            The value to assign to the auth_error_url property of this UpdateSlackChannelDetails.
        :type auth_error_url: str

        :param signing_secret:
            The value to assign to the signing_secret property of this UpdateSlackChannelDetails.
        :type signing_secret: str

        :param client_secret:
            The value to assign to the client_secret property of this UpdateSlackChannelDetails.
        :type client_secret: str

        :param bot_id:
            The value to assign to the bot_id property of this UpdateSlackChannelDetails.
        :type bot_id: str

        """
        self.swagger_types = {
            'description': 'str',
            'type': 'str',
            'session_expiry_duration_in_milliseconds': 'int',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'client_id': 'str',
            'auth_success_url': 'str',
            'auth_error_url': 'str',
            'signing_secret': 'str',
            'client_secret': 'str',
            'bot_id': 'str'
        }

        self.attribute_map = {
            'description': 'description',
            'type': 'type',
            'session_expiry_duration_in_milliseconds': 'sessionExpiryDurationInMilliseconds',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'client_id': 'clientId',
            'auth_success_url': 'authSuccessUrl',
            'auth_error_url': 'authErrorUrl',
            'signing_secret': 'signingSecret',
            'client_secret': 'clientSecret',
            'bot_id': 'botId'
        }

        self._description = None
        self._type = None
        self._session_expiry_duration_in_milliseconds = None
        self._freeform_tags = None
        self._defined_tags = None
        self._client_id = None
        self._auth_success_url = None
        self._auth_error_url = None
        self._signing_secret = None
        self._client_secret = None
        self._bot_id = None
        self._type = 'SLACK'

    @property
    def client_id(self):
        """
        Gets the client_id of this UpdateSlackChannelDetails.
        The Slack Client Id for the Slack app.


        :return: The client_id of this UpdateSlackChannelDetails.
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """
        Sets the client_id of this UpdateSlackChannelDetails.
        The Slack Client Id for the Slack app.


        :param client_id: The client_id of this UpdateSlackChannelDetails.
        :type: str
        """
        self._client_id = client_id

    @property
    def auth_success_url(self):
        """
        Gets the auth_success_url of this UpdateSlackChannelDetails.
        The URL to redirect to when authentication is successful.


        :return: The auth_success_url of this UpdateSlackChannelDetails.
        :rtype: str
        """
        return self._auth_success_url

    @auth_success_url.setter
    def auth_success_url(self, auth_success_url):
        """
        Sets the auth_success_url of this UpdateSlackChannelDetails.
        The URL to redirect to when authentication is successful.


        :param auth_success_url: The auth_success_url of this UpdateSlackChannelDetails.
        :type: str
        """
        self._auth_success_url = auth_success_url

    @property
    def auth_error_url(self):
        """
        Gets the auth_error_url of this UpdateSlackChannelDetails.
        The URL to redirect to when authentication is unsuccessful.


        :return: The auth_error_url of this UpdateSlackChannelDetails.
        :rtype: str
        """
        return self._auth_error_url

    @auth_error_url.setter
    def auth_error_url(self, auth_error_url):
        """
        Sets the auth_error_url of this UpdateSlackChannelDetails.
        The URL to redirect to when authentication is unsuccessful.


        :param auth_error_url: The auth_error_url of this UpdateSlackChannelDetails.
        :type: str
        """
        self._auth_error_url = auth_error_url

    @property
    def signing_secret(self):
        """
        Gets the signing_secret of this UpdateSlackChannelDetails.
        The Signing Secret for the Slack App.


        :return: The signing_secret of this UpdateSlackChannelDetails.
        :rtype: str
        """
        return self._signing_secret

    @signing_secret.setter
    def signing_secret(self, signing_secret):
        """
        Sets the signing_secret of this UpdateSlackChannelDetails.
        The Signing Secret for the Slack App.


        :param signing_secret: The signing_secret of this UpdateSlackChannelDetails.
        :type: str
        """
        self._signing_secret = signing_secret

    @property
    def client_secret(self):
        """
        Gets the client_secret of this UpdateSlackChannelDetails.
        The Client Secret for the Slack App.


        :return: The client_secret of this UpdateSlackChannelDetails.
        :rtype: str
        """
        return self._client_secret

    @client_secret.setter
    def client_secret(self, client_secret):
        """
        Sets the client_secret of this UpdateSlackChannelDetails.
        The Client Secret for the Slack App.


        :param client_secret: The client_secret of this UpdateSlackChannelDetails.
        :type: str
        """
        self._client_secret = client_secret

    @property
    def bot_id(self):
        """
        Gets the bot_id of this UpdateSlackChannelDetails.
        The ID of the Skill or Digital Assistant that the Channel is routed to.


        :return: The bot_id of this UpdateSlackChannelDetails.
        :rtype: str
        """
        return self._bot_id

    @bot_id.setter
    def bot_id(self, bot_id):
        """
        Sets the bot_id of this UpdateSlackChannelDetails.
        The ID of the Skill or Digital Assistant that the Channel is routed to.


        :param bot_id: The bot_id of this UpdateSlackChannelDetails.
        :type: str
        """
        self._bot_id = bot_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateApplicationDetails(object):
    """
    Properties used in application create operations.
    """

    #: A constant which can be used with the model_type property of a CreateApplicationDetails.
    #: This constant has a value of "INTEGRATION_APPLICATION"
    MODEL_TYPE_INTEGRATION_APPLICATION = "INTEGRATION_APPLICATION"

    #: A constant which can be used with the lifecycle_state property of a CreateApplicationDetails.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a CreateApplicationDetails.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a CreateApplicationDetails.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a CreateApplicationDetails.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a CreateApplicationDetails.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a CreateApplicationDetails.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateApplicationDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this CreateApplicationDetails.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this CreateApplicationDetails.
        :type model_version: str

        :param model_type:
            The value to assign to the model_type property of this CreateApplicationDetails.
            Allowed values for this property are: "INTEGRATION_APPLICATION"
        :type model_type: str

        :param name:
            The value to assign to the name property of this CreateApplicationDetails.
        :type name: str

        :param description:
            The value to assign to the description property of this CreateApplicationDetails.
        :type description: str

        :param object_status:
            The value to assign to the object_status property of this CreateApplicationDetails.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this CreateApplicationDetails.
        :type identifier: str

        :param display_name:
            The value to assign to the display_name property of this CreateApplicationDetails.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateApplicationDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateApplicationDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this CreateApplicationDetails.
            Allowed values for this property are: "CREATING", "ACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED"
        :type lifecycle_state: str

        :param source_application_info:
            The value to assign to the source_application_info property of this CreateApplicationDetails.
        :type source_application_info: oci.data_integration.models.CreateSourceApplicationInfo

        :param registry_metadata:
            The value to assign to the registry_metadata property of this CreateApplicationDetails.
        :type registry_metadata: oci.data_integration.models.RegistryMetadata

        """
        self.swagger_types = {
            'key': 'str',
            'model_version': 'str',
            'model_type': 'str',
            'name': 'str',
            'description': 'str',
            'object_status': 'int',
            'identifier': 'str',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'lifecycle_state': 'str',
            'source_application_info': 'CreateSourceApplicationInfo',
            'registry_metadata': 'RegistryMetadata'
        }

        self.attribute_map = {
            'key': 'key',
            'model_version': 'modelVersion',
            'model_type': 'modelType',
            'name': 'name',
            'description': 'description',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'lifecycle_state': 'lifecycleState',
            'source_application_info': 'sourceApplicationInfo',
            'registry_metadata': 'registryMetadata'
        }

        self._key = None
        self._model_version = None
        self._model_type = None
        self._name = None
        self._description = None
        self._object_status = None
        self._identifier = None
        self._display_name = None
        self._freeform_tags = None
        self._defined_tags = None
        self._lifecycle_state = None
        self._source_application_info = None
        self._registry_metadata = None

    @property
    def key(self):
        """
        Gets the key of this CreateApplicationDetails.
        Currently not used on application creation. Reserved for future.


        :return: The key of this CreateApplicationDetails.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this CreateApplicationDetails.
        Currently not used on application creation. Reserved for future.


        :param key: The key of this CreateApplicationDetails.
        :type: str
        """
        self._key = key

    @property
    def model_version(self):
        """
        Gets the model_version of this CreateApplicationDetails.
        The object's model version.


        :return: The model_version of this CreateApplicationDetails.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this CreateApplicationDetails.
        The object's model version.


        :param model_version: The model_version of this CreateApplicationDetails.
        :type: str
        """
        self._model_version = model_version

    @property
    def model_type(self):
        """
        Gets the model_type of this CreateApplicationDetails.
        The type of the application.

        Allowed values for this property are: "INTEGRATION_APPLICATION"


        :return: The model_type of this CreateApplicationDetails.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this CreateApplicationDetails.
        The type of the application.


        :param model_type: The model_type of this CreateApplicationDetails.
        :type: str
        """
        allowed_values = ["INTEGRATION_APPLICATION"]
        if not value_allowed_none_or_none_sentinel(model_type, allowed_values):
            raise ValueError(
                "Invalid value for `model_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._model_type = model_type

    @property
    def name(self):
        """
        **[Required]** Gets the name of this CreateApplicationDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this CreateApplicationDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CreateApplicationDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this CreateApplicationDetails.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this CreateApplicationDetails.
        Detailed description for the object.


        :return: The description of this CreateApplicationDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateApplicationDetails.
        Detailed description for the object.


        :param description: The description of this CreateApplicationDetails.
        :type: str
        """
        self._description = description

    @property
    def object_status(self):
        """
        Gets the object_status of this CreateApplicationDetails.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this CreateApplicationDetails.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this CreateApplicationDetails.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this CreateApplicationDetails.
        :type: int
        """
        self._object_status = object_status

    @property
    def identifier(self):
        """
        **[Required]** Gets the identifier of this CreateApplicationDetails.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :return: The identifier of this CreateApplicationDetails.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this CreateApplicationDetails.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :param identifier: The identifier of this CreateApplicationDetails.
        :type: str
        """
        self._identifier = identifier

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateApplicationDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The display_name of this CreateApplicationDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateApplicationDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param display_name: The display_name of this CreateApplicationDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateApplicationDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. See `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateApplicationDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateApplicationDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. See `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateApplicationDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateApplicationDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. See `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateApplicationDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateApplicationDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. See `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateApplicationDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this CreateApplicationDetails.
        The current state of the workspace.

        Allowed values for this property are: "CREATING", "ACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED"


        :return: The lifecycle_state of this CreateApplicationDetails.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this CreateApplicationDetails.
        The current state of the workspace.


        :param lifecycle_state: The lifecycle_state of this CreateApplicationDetails.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            raise ValueError(
                "Invalid value for `lifecycle_state`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._lifecycle_state = lifecycle_state

    @property
    def source_application_info(self):
        """
        Gets the source_application_info of this CreateApplicationDetails.

        :return: The source_application_info of this CreateApplicationDetails.
        :rtype: oci.data_integration.models.CreateSourceApplicationInfo
        """
        return self._source_application_info

    @source_application_info.setter
    def source_application_info(self, source_application_info):
        """
        Sets the source_application_info of this CreateApplicationDetails.

        :param source_application_info: The source_application_info of this CreateApplicationDetails.
        :type: oci.data_integration.models.CreateSourceApplicationInfo
        """
        self._source_application_info = source_application_info

    @property
    def registry_metadata(self):
        """
        Gets the registry_metadata of this CreateApplicationDetails.

        :return: The registry_metadata of this CreateApplicationDetails.
        :rtype: oci.data_integration.models.RegistryMetadata
        """
        return self._registry_metadata

    @registry_metadata.setter
    def registry_metadata(self, registry_metadata):
        """
        Sets the registry_metadata of this CreateApplicationDetails.

        :param registry_metadata: The registry_metadata of this CreateApplicationDetails.
        :type: oci.data_integration.models.RegistryMetadata
        """
        self._registry_metadata = registry_metadata

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class User(object):
    """
    User model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new User object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this User.
        :type id: str

        :param name:
            The value to assign to the name property of this User.
        :type name: str

        :param is_otp:
            The value to assign to the is_otp property of this User.
        :type is_otp: bool

        :param is_mfa_activated:
            The value to assign to the is_mfa_activated property of this User.
        :type is_mfa_activated: bool

        :param is_mfa_verified:
            The value to assign to the is_mfa_verified property of this User.
        :type is_mfa_verified: bool

        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'is_otp': 'bool',
            'is_mfa_activated': 'bool',
            'is_mfa_verified': 'bool'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'is_otp': 'isOTP',
            'is_mfa_activated': 'isMfaActivated',
            'is_mfa_verified': 'isMfaVerified'
        }

        self._id = None
        self._name = None
        self._is_otp = None
        self._is_mfa_activated = None
        self._is_mfa_verified = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this User.
        The user's Oracle ID (OCID).


        :return: The id of this User.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this User.
        The user's Oracle ID (OCID).


        :param id: The id of this User.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this User.
        The name of the user.


        :return: The name of this User.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this User.
        The name of the user.


        :param name: The name of this User.
        :type: str
        """
        self._name = name

    @property
    def is_otp(self):
        """
        **[Required]** Gets the is_otp of this User.
        If the provided password is a one-time password.


        :return: The is_otp of this User.
        :rtype: bool
        """
        return self._is_otp

    @is_otp.setter
    def is_otp(self, is_otp):
        """
        Sets the is_otp of this User.
        If the provided password is a one-time password.


        :param is_otp: The is_otp of this User.
        :type: bool
        """
        self._is_otp = is_otp

    @property
    def is_mfa_activated(self):
        """
        **[Required]** Gets the is_mfa_activated of this User.
        If mfa is activated.


        :return: The is_mfa_activated of this User.
        :rtype: bool
        """
        return self._is_mfa_activated

    @is_mfa_activated.setter
    def is_mfa_activated(self, is_mfa_activated):
        """
        Sets the is_mfa_activated of this User.
        If mfa is activated.


        :param is_mfa_activated: The is_mfa_activated of this User.
        :type: bool
        """
        self._is_mfa_activated = is_mfa_activated

    @property
    def is_mfa_verified(self):
        """
        **[Required]** Gets the is_mfa_verified of this User.
        If the user has been mfa verified.


        :return: The is_mfa_verified of this User.
        :rtype: bool
        """
        return self._is_mfa_verified

    @is_mfa_verified.setter
    def is_mfa_verified(self, is_mfa_verified):
        """
        Sets the is_mfa_verified of this User.
        If the user has been mfa verified.


        :param is_mfa_verified: The is_mfa_verified of this User.
        :type: bool
        """
        self._is_mfa_verified = is_mfa_verified

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ApiSpecificationRouteResponsePolicies(object):
    """
    Behavior applied to any responses sent by the API for requests on this route.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ApiSpecificationRouteResponsePolicies object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param header_transformations:
            The value to assign to the header_transformations property of this ApiSpecificationRouteResponsePolicies.
        :type header_transformations: oci.apigateway.models.HeaderTransformationPolicy

        :param response_cache_store:
            The value to assign to the response_cache_store property of this ApiSpecificationRouteResponsePolicies.
        :type response_cache_store: oci.apigateway.models.ResponseCacheStorePolicy

        """
        self.swagger_types = {
            'header_transformations': 'HeaderTransformationPolicy',
            'response_cache_store': 'ResponseCacheStorePolicy'
        }

        self.attribute_map = {
            'header_transformations': 'headerTransformations',
            'response_cache_store': 'responseCacheStore'
        }

        self._header_transformations = None
        self._response_cache_store = None

    @property
    def header_transformations(self):
        """
        Gets the header_transformations of this ApiSpecificationRouteResponsePolicies.

        :return: The header_transformations of this ApiSpecificationRouteResponsePolicies.
        :rtype: oci.apigateway.models.HeaderTransformationPolicy
        """
        return self._header_transformations

    @header_transformations.setter
    def header_transformations(self, header_transformations):
        """
        Sets the header_transformations of this ApiSpecificationRouteResponsePolicies.

        :param header_transformations: The header_transformations of this ApiSpecificationRouteResponsePolicies.
        :type: oci.apigateway.models.HeaderTransformationPolicy
        """
        self._header_transformations = header_transformations

    @property
    def response_cache_store(self):
        """
        Gets the response_cache_store of this ApiSpecificationRouteResponsePolicies.

        :return: The response_cache_store of this ApiSpecificationRouteResponsePolicies.
        :rtype: oci.apigateway.models.ResponseCacheStorePolicy
        """
        return self._response_cache_store

    @response_cache_store.setter
    def response_cache_store(self, response_cache_store):
        """
        Sets the response_cache_store of this ApiSpecificationRouteResponsePolicies.

        :param response_cache_store: The response_cache_store of this ApiSpecificationRouteResponsePolicies.
        :type: oci.apigateway.models.ResponseCacheStorePolicy
        """
        self._response_cache_store = response_cache_store

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDashboardGroupDetails(object):
    """
    The data to create a new dashboard group.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDashboardGroupDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateDashboardGroupDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this CreateDashboardGroupDetails.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateDashboardGroupDetails.
        :type compartment_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateDashboardGroupDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateDashboardGroupDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'description': 'str',
            'compartment_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._description = None
        self._compartment_id = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateDashboardGroupDetails.
        A user-friendly name for the dashboard. Does not have to be unique, and it can be changed. Avoid entering confidential information.
        Leading and trailing spaces and the following special characters are not allowed: <>()=/'\"&\\


        :return: The display_name of this CreateDashboardGroupDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateDashboardGroupDetails.
        A user-friendly name for the dashboard. Does not have to be unique, and it can be changed. Avoid entering confidential information.
        Leading and trailing spaces and the following special characters are not allowed: <>()=/'\"&\\


        :param display_name: The display_name of this CreateDashboardGroupDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this CreateDashboardGroupDetails.
        A short description of the dashboard group. It can be changed. Avoid entering confidential information.
        The following special characters are not allowed: <>()=/'\"&\\


        :return: The description of this CreateDashboardGroupDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateDashboardGroupDetails.
        A short description of the dashboard group. It can be changed. Avoid entering confidential information.
        The following special characters are not allowed: <>()=/'\"&\\


        :param description: The description of this CreateDashboardGroupDetails.
        :type: str
        """
        self._description = description

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateDashboardGroupDetails.
        The `OCID`__ of the compartment containing the dashboard group.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateDashboardGroupDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateDashboardGroupDetails.
        The `OCID`__ of the compartment containing the dashboard group.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateDashboardGroupDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateDashboardGroupDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this CreateDashboardGroupDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateDashboardGroupDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this CreateDashboardGroupDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateDashboardGroupDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this CreateDashboardGroupDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateDashboardGroupDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this CreateDashboardGroupDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .certificate_rule import CertificateRule
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CertificateRenewalRule(CertificateRule):
    """
    A rule that imposes constraints on certificate renewal.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CertificateRenewalRule object with values from keyword arguments. The default value of the :py:attr:`~oci.certificates_management.models.CertificateRenewalRule.rule_type` attribute
        of this class is ``CERTIFICATE_RENEWAL_RULE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param rule_type:
            The value to assign to the rule_type property of this CertificateRenewalRule.
            Allowed values for this property are: "CERTIFICATE_RENEWAL_RULE"
        :type rule_type: str

        :param renewal_interval:
            The value to assign to the renewal_interval property of this CertificateRenewalRule.
        :type renewal_interval: str

        :param advance_renewal_period:
            The value to assign to the advance_renewal_period property of this CertificateRenewalRule.
        :type advance_renewal_period: str

        """
        self.swagger_types = {
            'rule_type': 'str',
            'renewal_interval': 'str',
            'advance_renewal_period': 'str'
        }

        self.attribute_map = {
            'rule_type': 'ruleType',
            'renewal_interval': 'renewalInterval',
            'advance_renewal_period': 'advanceRenewalPeriod'
        }

        self._rule_type = None
        self._renewal_interval = None
        self._advance_renewal_period = None
        self._rule_type = 'CERTIFICATE_RENEWAL_RULE'

    @property
    def renewal_interval(self):
        """
        **[Required]** Gets the renewal_interval of this CertificateRenewalRule.
        A property specifying how often, in days, a certificate should be renewed.
        Expressed in `ISO 8601`__ format.

        __ https://en.wikipedia.org/wiki/ISO_8601#Time_intervals


        :return: The renewal_interval of this CertificateRenewalRule.
        :rtype: str
        """
        return self._renewal_interval

    @renewal_interval.setter
    def renewal_interval(self, renewal_interval):
        """
        Sets the renewal_interval of this CertificateRenewalRule.
        A property specifying how often, in days, a certificate should be renewed.
        Expressed in `ISO 8601`__ format.

        __ https://en.wikipedia.org/wiki/ISO_8601#Time_intervals


        :param renewal_interval: The renewal_interval of this CertificateRenewalRule.
        :type: str
        """
        self._renewal_interval = renewal_interval

    @property
    def advance_renewal_period(self):
        """
        **[Required]** Gets the advance_renewal_period of this CertificateRenewalRule.
        A property specifying the period of time, in days, before the certificate's targeted renewal that the process should occur.
        Expressed in `ISO 8601`__ format.

        __ https://en.wikipedia.org/wiki/ISO_8601#Time_intervals


        :return: The advance_renewal_period of this CertificateRenewalRule.
        :rtype: str
        """
        return self._advance_renewal_period

    @advance_renewal_period.setter
    def advance_renewal_period(self, advance_renewal_period):
        """
        Sets the advance_renewal_period of this CertificateRenewalRule.
        A property specifying the period of time, in days, before the certificate's targeted renewal that the process should occur.
        Expressed in `ISO 8601`__ format.

        __ https://en.wikipedia.org/wiki/ISO_8601#Time_intervals


        :param advance_renewal_period: The advance_renewal_period of this CertificateRenewalRule.
        :type: str
        """
        self._advance_renewal_period = advance_renewal_period

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import


from .commitment_client import CommitmentClient
from .commitment_client_composite_operations import CommitmentClientCompositeOperations
from .ratecard_client import RatecardClient
from .ratecard_client_composite_operations import RatecardClientCompositeOperations
from .subscription_client import SubscriptionClient
from .subscription_client_composite_operations import SubscriptionClientCompositeOperations
from . import models

__all__ = ["CommitmentClient", "CommitmentClientCompositeOperations", "RatecardClient", "RatecardClientCompositeOperations", "SubscriptionClient", "SubscriptionClientCompositeOperations", "models"]
